from setuptools import setup

setup(name='fasmetrics',
      version='0.1',
      description='FAS metrics implementations (APCER, BPCER, ACER)',
      packages=['fasmetrics'],
      author='Guilherme Baldo Carlos',
      author_email='guilhermebaldocarlos@gmail.com',
      zip_safe=False)